package com.xuqm.server.appmanager.controller.sys.v1;

import com.xuqm.server.appmanager.common.CommonHelper;
import com.xuqm.server.appmanager.common.JWTHelper;
import com.xuqm.server.appmanager.controller.sys.v1.data.TenantAddUserData;
import com.xuqm.server.appmanager.controller.sys.v1.data.TenantChangeAdminData;
import com.xuqm.server.appmanager.controller.sys.v1.data.TenantCreateData;
import com.xuqm.server.appmanager.controller.sys.v1.data.TenantDelUserData;
import com.xuqm.server.appmanager.entitys.UserInfo;
import com.xuqm.server.appmanager.entitys.sys.v1.TenantEntity;
import com.xuqm.server.appmanager.entitys.sys.v1.TenantUserEntity;
import com.xuqm.server.appmanager.http.HttpResult;
import com.xuqm.server.appmanager.repository.sys.v1.TenantRepository;
import com.xuqm.server.appmanager.repository.sys.v1.TenantUserRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Objects;

@RestController
@RequestMapping("tenant/v1")
public class TenantV1Controller {

    @Autowired
    private TenantRepository tenantRepository;
    @Autowired
    private TenantUserRepository tenantUserRepository;

    @PostMapping("/create")
    public HttpResult<String> tenantCreate(@RequestBody TenantCreateData tenant) throws Exception {
        if (null == tenant.getUserPhone() || null == tenant.getUserEmail() || null == tenant.getUserPwd()) {
            return new HttpResult<>(201, "参数错误", null);
        } else {
            TenantUserEntity u = tenantUserRepository.findFirstByUserEmailOrUserPhone(tenant.getUserEmail(), tenant.getUserPhone());
            if (null != u) return new HttpResult<>(201, "邮箱或手机号重复", null);
            u = new TenantUserEntity();
            u.setUserEmail(tenant.getUserEmail());
            u.setUserPhone(tenant.getUserPhone());
            u.setUserPwd(tenant.getUserPwd());
            u.setUserName(tenant.getUserName());
            u.setUserId(CommonHelper.getRandomId());
            u.setTenantNo(CommonHelper.getRandomId());
            tenantUserRepository.save(u);
            TenantEntity t = new TenantEntity();
            t.setUserId(u.getUserId());
            t.setTenantNo(u.getTenantNo());
            t.setTenantName(tenant.getTenantName());
            tenantRepository.save(t);

            return new HttpResult<>(200, "创建成功", "创建成功");
        }

    }

    @PostMapping("/changeAdmin")
    public HttpResult<String> changeAdmin(@RequestBody TenantChangeAdminData data, @RequestHeader(name = "token") String token) throws Exception {
        UserInfo userInfo = JWTHelper.getUser(token);
        if (null == userInfo) {
            return new HttpResult<>(401, "登录失效", null);
        }
        if (null == data.getUserId()) {
            return new HttpResult<>(201, "参数错误", null);
        } else {
            TenantEntity tenant = tenantRepository.findFirstByTenantNo(userInfo.getTenantNo());
            if (null == tenant) return new HttpResult<>(201, "查找租户信息失败", null);
            if (!Objects.equals(tenant.getUserId(), userInfo.getUserId())) {
                return new HttpResult<>(201, "请用管理员账号操作", null);
            }
            tenant.setUserId(data.getUserId());
            tenantRepository.save(tenant);

            return new HttpResult<>(200, "修改成功", "修改成功");
        }

    }

    @PostMapping("/addUser")
    public HttpResult<String> addUser(@RequestBody TenantAddUserData data, @RequestHeader(name = "token") String token) throws Exception {
        UserInfo userInfo = JWTHelper.getUser(token);
        if (null == userInfo) {
            return new HttpResult<>(401, "登录失效", null);
        }
        if (null == data.getUserPhone() || null == data.getUserEmail() || null == data.getUserPwd()) {
            return new HttpResult<>(201, "参数错误", null);
        } else {
            TenantUserEntity u = tenantUserRepository.findFirstByUserEmailOrUserPhone(data.getUserEmail(), data.getUserPhone());
            if (null != u) return new HttpResult<>(201, "邮箱或手机号重复", null);
            u = new TenantUserEntity();
            u.setUserEmail(data.getUserEmail());
            u.setUserPhone(data.getUserPhone());
            u.setUserPwd(data.getUserPwd());
            u.setUserName(data.getUserName());
            u.setUserId(CommonHelper.getRandomId());
            u.setTenantNo(userInfo.getTenantNo());
            tenantUserRepository.save(u);

            return new HttpResult<>(200, "添加成功", "添加成功");
        }

    }

    @PostMapping("/delUser")
    public HttpResult<String> delUser(@RequestBody TenantDelUserData data, @RequestHeader(name = "token") String token) throws Exception {
        UserInfo userInfo = JWTHelper.getUser(token);
        if (null == userInfo) {
            return new HttpResult<>(401, "登录失效", null);
        }
        if (null == data.getUserId()) {
            return new HttpResult<>(201, "参数错误", null);
        } else {
            TenantEntity tenant = tenantRepository.findFirstByTenantNo(userInfo.getTenantNo());
            if (null == tenant) return new HttpResult<>(201, "查找租户信息失败", null);
            if (!Objects.equals(tenant.getUserId(), userInfo.getUserId())) {
                return new HttpResult<>(201, "请用管理员账号操作", null);
            }
            if (!Objects.equals(tenant.getUserId(), data.getUserId())) {
                return new HttpResult<>(201, "无法删除管理员账号", null);
            }

            tenantUserRepository.delete(tenantUserRepository.findFirstByUserId(data.getUserId()));

            return new HttpResult<>(200, "删除成功", "删除成功");
        }

    }

}
